==> python-molecule_24.7.0.orig.tar.gz: tests/unit/test_api.py <==
#  Copyright (c) 2019 Red Hat, Inc.  # noqa: D100
#  Copyright (c) 2015-2018 Cisco Systems, Inc.
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to
#  deal in the Software without restriction, including without limitation the
#  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
#  sell copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in
#  all copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#  DEALINGS IN THE SOFTWARE.

from molecule import api


def test_api_molecule_drivers_as_attributes():  # type: ignore[no-untyped-def]  # noqa: ANN201, D103
    results = api.drivers()
    assert hasattr(results, "default")
    assert isinstance(results.default, api.Driver)  # type: ignore[attr-defined] # pylint:disable=no-member


def test_api_drivers():  # type: ignore[no-untyped-def]  # noqa: ANN201, D103
    results = api.drivers()

    for result in results:
        assert isinstance(result, api.Driver)  # type: ignore[attr-defined]

    assert "default" in results


def test_api_verifiers():  # type: ignore[no-untyped-def]  # noqa: ANN201, D103
    x = ["testinfra", "ansible"]

    assert all(elem in api.verifiers() for elem in x)

==> python-molecule_24.12.0.orig.tar.gz: tests/unit/test_api.py <==
#  Copyright (c) 2019 Red Hat, Inc.  # noqa: D100
#  Copyright (c) 2015-2018 Cisco Systems, Inc.
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to
#  deal in the Software without restriction, including without limitation the
#  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
#  sell copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in
#  all copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#  DEALINGS IN THE SOFTWARE.
from __future__ import annotations

from molecule import api


def test_api_drivers() -> None:  # noqa: D103
    results = api.drivers()

    for result in results.values():
        assert isinstance(result, api.Driver)

    assert "default" in results


def test_api_verifiers() -> None:  # noqa: D103
    x = ["testinfra", "ansible"]

    assert all(elem in api.verifiers() for elem in x)
